from __future__ import unicode_literals

__all__ = "yt_download"

import os


def my_hook(d):
    if d['status'] == 'finished':
        print('Done downloading, now converting ...')


def yt_download(url, filename=None, ismusic=False, video_format=None, hooks=None, logger=None, overwrite=True,codec = None,
                **ydl_opts):
    if hooks is None:
        hooks = [my_hook]

    import youtube_dl
    import os
    if video_format is None:
        video_format = os.path.splitext(filename)[1][1:]
    if not ismusic:
        ydl_opts["format"] = video_format
    if ismusic:
        ydl_opts.update({
            'format': 'bestaudio/best',
            'postprocessors': [{
                'key': 'FFmpegExtractAudio',
                'preferredcodec': codec if codec else video_format ,
                'preferredquality': '192'
            }],
        })
    if logger:
        ydl_opts["logger"] = logger
    if hooks:
        ydl_opts["progress_hooks"] = hooks
    if filename is not None:
        ydl_opts["outtmpl"] = filename
    if overwrite:
        if os.path.exists(filename):
            print(f"overwrite file {filename}")
            os.remove(filename)
        ##########################
    print(f"download {url} in format {video_format} to file {filename}")

    #############################################
    with youtube_dl.YoutubeDL(ydl_opts) as ydl:
        ydl.download([url])


def _get_ffmpeg_path():
    err = os.system("ffmpeg -version")
    if err == 0:  # ffmpeg in path
        ffmpeg = "ffmpeg"
    else:  # not in Path
        import imageio_ffmpeg
        ffmpeg = imageio_ffmpeg.get_ffmpeg_exe()

    ffmpeg = '\"' + ffmpeg + '\"'
    return ffmpeg



import setuptools
with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
    name='mhyt',  # How you named your package folder (MyLib)
    version='3.5.5',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='download files from youtube using simple code',  # Give a short description about your library
    author='matan h',  # Type in your name
    author_email='matan.honig2@gmail.com',  # Type in your E-Mail
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/matan-h/mhyt",
    packages=['mhyt'],
    install_requires=["youtube-dl","imageio_ffmpeg"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.0',
)
